import { Rows } from "./rows";
import { Columns } from "./columns";
import { cellType, DataTableOptions, nodeType, renderOptions, TableDataType } from "./interfaces";
export declare class DataTable {
    columns: Columns;
    container: HTMLDivElement;
    currentPage: number;
    data: TableDataType;
    dd: any;
    dom: HTMLTableElement;
    events: {
        [key: string]: ((...args: any[]) => void)[];
    };
    filterStates: any;
    hasHeadings: boolean;
    hasRows: boolean;
    headerDOM: HTMLDivElement;
    id: string;
    initialInnerHTML: string;
    initialized: boolean;
    input: HTMLInputElement;
    label: HTMLElement;
    lastPage: number;
    links: HTMLElement[];
    listeners: {
        [key: string]: () => void;
    };
    onFirstPage: boolean;
    onLastPage: boolean;
    options: DataTableOptions;
    pagers: HTMLUListElement[];
    pages: {
        row: cellType[];
        index: number;
    }[][];
    rect: {
        width: number;
        height: number;
    };
    rows: Rows;
    searchData: number[];
    searching: boolean;
    totalPages: number;
    virtualDOM: nodeType;
    virtualHeaderDOM: nodeType;
    wrapper: HTMLElement;
    constructor(table: HTMLTableElement | string, options?: DataTableOptions);
    /**
     * Initialize the instance
     */
    init(): boolean;
    /**
     * Render the instance
     */
    _render(): void;
    _renderTable(renderOptions?: renderOptions): void;
    /**
     * Render the page
     * @return {Void}
     */
    _renderPage(lastRowCursor?: boolean): void;
    /**
     * Render the pager(s)
     * @return {Void}
     */
    _renderPager(): void;
    _renderSeparateHeader(): void;
    /**
     * Bind event listeners
     * @return {[type]} [description]
     */
    _bindEvents(): void;
    /**
     * execute on resize
     */
    _onResize(): void;
    /**
     * Destroy the instance
     * @return {void}
     */
    destroy(): void;
    /**
     * Update the instance
     * @return {Void}
     */
    update(measureWidths?: boolean): void;
    _paginate(): number;
    /**
     * Fix the container height
     */
    _fixHeight(): void;
    /**
     * Perform a search of the data set
     */
    search(query: string): boolean;
    /**
     * Change page
     */
    page(page: number, lastRowCursor?: boolean): boolean;
    /**
     * Add new row data
     */
    insert(data: any): void;
    /**
     * Refresh the instance
     */
    refresh(): void;
    /**
     * Print the table
     */
    print(): void;
    /**
     * Show a message in the table
     */
    setMessage(message: string): void;
    /**
     * Add custom event listener
     */
    on(event: string, callback: () => void): void;
    /**
     * Remove custom event listener
     */
    off(event: string, callback: () => void): void;
    /**
     * Fire custom event
     */
    emit(event: string, ...args: any[]): void;
}
